@@ -89,6 +89,7 @@ pub static ATOMS: &'static [&'static str] = &[
     "http://www.w3.org/1998/Math/MathML",
 
     "abbr",
+    "abort",
     "abs",
     "accent",
     "accent-height",
@@ -103,6 +104,7 @@ pub static ATOMS: &'static [&'static str] = &[
     "active",
     "actuate",
     "additive",
+    "afterscriptexecute",
     "align",
     "alignment-baseline",
     "alignmentscope",
@@ -214,6 +216,7 @@ pub static ATOMS: &'static [&'static str] = &[
     "bbox",
     "bdi",
     "bdo",
+    "beforescriptexecute",
     "beforeunload",
     "begin",
     "bevelled",
@@ -258,6 +261,7 @@ pub static ATOMS: &'static [&'static str] = &[
     "cellpadding",
     "cellspacing",
     "center",
+    "change",
     "char",
     "charoff",
     "charset",
@@ -367,6 +371,7 @@ pub static ATOMS: &'static [&'static str] = &[
     "dl",
     "domain",
     "domainofapplication",
+    "DOMContentLoaded",
     "dominant-baseline",
     "draggable",
     "dur",
@@ -614,6 +619,9 @@ pub static ATOMS: &'static [&'static str] = &[
     "list-style-position",
     "list-style-type",
     "ln",
+    "load",
+    "loadstart",
+    "loadend",
     "local",
     "log",
     "logbase",
@@ -676,6 +684,7 @@ pub static ATOMS: &'static [&'static str] = &[
     "menu",
     "menuitem",
     "merror",
+    "message",
     "metadata",
     "meter",
     "method",
@@ -926,6 +935,7 @@ pub static ATOMS: &'static [&'static str] = &[
     "rationals",
     "rb",
     "readonly",
+    "readystatechange",
     "real",
     "reals",
     "rect",
@@ -1041,6 +1051,7 @@ pub static ATOMS: &'static [&'static str] = &[
     "stop",
     "stop-color",
     "stop-opacity",
+    "storage",
     "stretchy",
     "strike",
     "strikethrough-position",
@@ -1160,6 +1171,7 @@ pub static ATOMS: &'static [&'static str] = &[
     "v-mathematical",
     "vspace",
     "wbr",
+    "webglcontextcreationerror",
     "week",
     "when",
     "white-space",
